@@ -1,6 +1,6 @@
 package Devel::PatchPerl;
 {
-  $Devel::PatchPerl::VERSION = '0.52';
+  $Devel::PatchPerl::VERSION = '0.54';
 }
 
 # ABSTRACT: Patch perl source a la Devel::PPPort's buildperl.pl
@@ -131,6 +131,14 @@ my @patch = (
               [ \&_patch_odbm_file_hints_linux ],
             ],
   },
+  {
+    perl => [
+              qr/(?^:5.1(?:[24].\d+|0.1))/,
+            ],
+    subs => [
+              [ \&_patch_make_ext_pl ],
+            ],
+  },
 );
 
 sub patch_source {
@@ -1716,6 +1724,27 @@ sub _patch_odbm_file_hints_linux
 END
 }
 
+sub _patch_make_ext_pl
+{
+  _patch(<<'END');
+diff --git a/make_ext.pl b/make_ext.pl
+index 13a15b4..6425e37 100644
+--- a/make_ext.pl
++++ b/make_ext.pl
+@@ -377,6 +377,10 @@ WriteMakefile(
+ EOM
+ 	    close $fh or die "Can't close Makefile.PL: $!";
+ 	}
++  eval {
++    my $ftime = time - 4;
++    utime $ftime, $ftime, 'Makefile.PL';
++  };
+ 	print "\nRunning Makefile.PL in $ext_dir\n";
+ 
+ 	# Presumably this can be simplified
+END
+}
+
 qq[patchin'];
 
 
@@ -1729,7 +1758,7 @@ Devel::PatchPerl - Patch perl source a la Devel::PPPort's buildperl.pl
 
 =head1 VERSION
 
-version 0.52
+version 0.54
 
 =head1 SYNOPSIS
 
